async fn download_range(
blob: &BlobClient,
offset: u64,
etag: Option<Etag>,
) -> Result<Option<BlobClientDownloadResult>, ExternalError>Expand description
Downloads the partition of blob that starts at offset, or returns
None if the blob does not exist.
With etag, the download fails if the blob no longer has that etag.