fn download_total_len(headers: &Headers) -> Option<u64>Expand description
Returns the total size of the blob a download response is for.
A ranged response reports the total after the slash of its
Content-Range header, e.g. bytes 0-1023/4096. A full response only
has a Content-Length.