fn emulator_sas_token() -> Result<String>Expand description
Returns an account SAS query string that grants full access to the emulator’s blob service, signed with the emulator’s well-known account key.
The Azure SDK does not support shared key authorization, which is what the emulator’s account key is otherwise used for.